@@ -1,21 +1,27 @@
 import getpass
+import json
 import logging
 import os
 import pathlib
+import sys
 import warnings
 from unittest.mock import patch
 
 import pytest
 from jupyter_core.application import NoStart
+from tornado import web
 from traitlets import TraitError
 from traitlets.config import Config
 from traitlets.tests.utils import check_help_all_output
 
+from jupyter_server.auth.decorator import allow_unauthenticated, authorized
 from jupyter_server.auth.security import passwd_check
 from jupyter_server.serverapp import (
     JupyterPasswordApp,
+    JupyterServerListApp,
     ServerApp,
     ServerWebApplication,
+    _has_tornado_web_authenticated,
     list_running_servers,
     random_ports,
 )
@@ -36,6 +42,49 @@ def test_help_output():
     check_help_all_output("jupyter_server")
 
 
+@pytest.mark.parametrize(
+    "format",
+    [
+        "json",
+        "jsonlist",
+        "",
+    ],
+)
+def test_server_list(jp_configurable_serverapp, capsys, format):
+    app = jp_configurable_serverapp(log=logging.getLogger())
+
+    app.write_server_info_file()
+
+    capsys.readouterr()
+    listapp = JupyterServerListApp(
+        parent=app,
+    )
+    if format:
+        setattr(listapp, format, True)
+    listapp.start()
+    captured = capsys.readouterr()
+    sys.stdout.write(captured.out)
+    sys.stderr.write(captured.err)
+    out = captured.out.strip()
+
+    if not format:
+        assert "Currently running servers:" in out
+        assert app.connection_url in out
+        assert len(out.splitlines()) == 2
+        return
+
+    if format == "jsonlist":
+        servers = json.loads(out)
+    elif format == "json":
+        servers = [json.loads(line) for line in out.splitlines()]
+    assert len(servers) == 1
+    sinfo = servers[0]
+
+    assert sinfo["port"] == app.port
+    assert sinfo["url"] == app.connection_url
+    assert sinfo["version"] == app.version
+
+
 def test_server_info_file(tmp_path, jp_configurable_serverapp):
     app = jp_configurable_serverapp(log=logging.getLogger())
 
@@ -52,7 +101,7 @@ def test_server_info_file(tmp_path, jp_configurable_serverapp):
     app.remove_server_info_file()
 
     assert list(list_running_servers(app.runtime_dir)) == []
-    app.remove_server_info_file
+    app.remove_server_info_file()
 
 
 def test_root_dir(tmp_path, jp_configurable_serverapp):
@@ -117,12 +166,32 @@ def test_server_password(tmp_path, jp_configurable_serverapp):
         passwd_check(sv.identity_provider.hashed_password, password)
 
 
+@pytest.mark.parametrize(
+    "env,expected",
+    [
+        ["yes", True],
+        ["Yes", True],
+        ["True", True],
+        ["true", True],
+        ["TRUE", True],
+        ["no", False],
+        ["nooo", False],
+        ["FALSE", False],
+        ["false", False],
+    ],
+)
+def test_allow_unauthenticated_env_var(jp_configurable_serverapp, env, expected):
+    with patch.dict("os.environ", {"JUPYTER_SERVER_ALLOW_UNAUTHENTICATED_ACCESS": env}):
+        app = jp_configurable_serverapp()
+        assert app.allow_unauthenticated_access == expected
+
+
 def test_list_running_servers(jp_serverapp, jp_web_app):
     servers = list(list_running_servers(jp_serverapp.runtime_dir))
     assert len(servers) >= 1
 
 
-@pytest.fixture
+@pytest.fixture()
 def prefix_path(jp_root_dir, tmp_path):
     """If a given path is prefixed with the literal
     strings `/jp_root_dir` or `/tmp_path`, replace those
@@ -390,7 +459,7 @@ def test_preferred_dir_validation(
         config_file.write_text("\n".join(config_lines))
 
     if argv:
-        kwargs["argv"] = argv  # type:ignore
+        kwargs["argv"] = argv  # type:ignore[assignment]
 
     if root_dir_loc == "default" and preferred_dir_loc != "default":  # error expected
         with pytest.raises(SystemExit):
@@ -479,7 +548,7 @@ def test_server_web_application(jp_serverapp):
             server.kernel_manager,
             server.config_manager,
             server.event_logger,
-            ["jupyter_server.gateway.handlers"],
+            [],
             server.log,
             server.base_url,
             server.default_url,
@@ -525,7 +594,7 @@ def test_signals(jp_serverapp):
 async def test_shutdown_no_activity(jp_serverapp):
     app: ServerApp = jp_serverapp
     app.extension_manager.extensions = {}
-    app.exit = lambda _: None  # type:ignore
+    app.exit = lambda _: None  # type:ignore[assignment,misc]
     app.shutdown_no_activity()
     app.shutdown_no_activity_timeout = 1
     app.init_shutdown_no_activity()
@@ -561,3 +630,32 @@ def test_deprecated_notebook_dir_priority(jp_configurable_serverapp, tmp_path):
     cfg.ServerApp.notebook_dir = str(notebook_dir)
     app.update_config(cfg)
     assert app.root_dir == str(cli_dir)
+
+
+def test_immutable_cache_trait():
+    # Verify we're working with a clean instance.
+    ServerApp.clear_instance()
+    kwargs = {"static_immutable_cache": "/test/immutable"}
+    serverapp = ServerApp.instance(**kwargs)
+    serverapp.init_configurables()
+    serverapp.init_webapp()
+    assert serverapp.web_app.settings["static_immutable_cache"] == ["/test/immutable"]
+
+
+def test():
+    pass
+
+
+@pytest.mark.parametrize(
+    "method, expected",
+    [
+        [test, False],
+        [allow_unauthenticated(test), False],
+        [authorized(test), False],
+        [web.authenticated(test), True],
+        [web.authenticated(authorized(test)), True],
+        [authorized(web.authenticated(test)), False],  # wrong order!
+    ],
+)
+def test_tornado_authentication_detection(method, expected):
+    assert _has_tornado_web_authenticated(method) == expected
